@@ -4,8 +4,7 @@ from past.builtins import basestring, long
 from future.utils import PY2, PY3, with_metaclass
 from datetime import date, timedelta
 import calendar
-
-# import sys
+from . import scripts
 
 
 __title__ = 'python_plus'
@@ -16,13 +15,14 @@ __ver_major__ = 0
 __ver_minor__ = 1
 __ver_patch__ = 3
 __ver_sub__ = '6'
-__version__ = '2.0.0'
+__version__ = '2.0.1'
 
 PYCODESET = 'utf-8'
 if PY3:
     text_type = unicode = str
     bytestr_type = bytes
 elif PY2:
+    # unicode exist only for python2
     text_type = unicode
     bytestr_type = str
 
@@ -147,16 +147,6 @@ def qsplit(*args, **kwargs):
     return result
 
 
-# if PY3:
-#     def qsplit(src, sep=None, maxsplit=-1,
-#                 quotes=None, escape=None, enquote=None, strip=None):
-#         return __qsplit__(src, sep=sep, maxsplit=maxsplit, quotes=quotes,
-#                           escape=escape, enquote=enquote, strip=strip)
-# if PY2:
-#     def qsplit(*args, **kwargs):
-#         return __qsplit__(*args, **kwargs)
-
-
 def compute_date(value, refdate=None):
     """Evaluate an encoded date string against reference date or today().
     This function applies for some standard python date[time] functions;
